@@ -1,16 +1,11 @@
 import binascii
 import getpass
-import gzip
 import hashlib
-import http.cookiejar
 import json
 import os
-import pathlib
 import shutil
-import subprocess
 import time
-import urllib
-from typing import Any, TypeVar, Union
+from typing import Any, Optional, Union
 
 
 def openWindowsFolder(folder: str):
@@ -21,8 +16,12 @@ def getPath(basePath: str, *parList: str) -> str:
     return os.path.abspath(os.path.join(basePath, *parList))
 
 
-def getDesktopPath(*parList: Any):
-    return getPath(os.path.expanduser("~"), "Desktop", *parList)
+def getUserPath(*parList: str):
+    return getPath(os.path.expanduser("~"), *parList)
+
+
+def getDesktopPath(*parList: str):
+    return getUserPath("Desktop", *parList)
 
 
 def writeFile(file: str, data: str, encoding: str = 'utf8', newline: str = '\n'):
@@ -208,62 +207,6 @@ def makeTempWorkspace(clearOneDayBefore: bool = True):
     raise Exception("创建tempWorkspace目录失败")
 
 
-def execute(*pars: str, showCmd: bool = True, showOutput: bool = False, ignoreError: bool = False):
-    from . import log
-    cmd = ' '.join(pars)
-    if showCmd:
-        log.info(cmd)
-    p = subprocess.Popen(
-        cmd,
-        shell=True,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE
-    )
-    outBytes, errBytes = p.communicate()
-    p.kill()
-    if showOutput:
-        from .byte import decode
-        outStr = decode(outBytes).replace("\r\n", "\n")
-        errStr = decode(errBytes).replace("\r\n", "\n")
-        if outStr:
-            log.info(f"output:\n{outStr}")
-        if errStr:
-            log.info(f"error:\n{errStr}")
-    if not ignoreError and p.returncode != 0:
-        raise Exception("执行命令出错")
-    return p.returncode, outBytes, errBytes
-
-
-def executeWinScp(winscpExe: str, keyFile: str, server: str, commandAry: list[str], showCmd: bool = True):
-    logFile = getPath(str(pathlib.Path.home()), "executeWinScp.log")
-    remove(logFile)
-    ary = [
-        'option batch abort',
-        'option transfer binary',
-        f'open sftp://{server} -privatekey={keyFile} -hostkey=*',
-    ]
-    ary += commandAry
-    ary += [
-        'close',
-        'exit',
-    ]
-    # /console
-    cmd = f'{winscpExe} /log={logFile} /loglevel=0 /command ' + ' '.join('"%s"' % x for x in ary)
-    return execute(cmd, showCmd=showCmd)
-
-
-def executeTry(*parList: str, output: str = "", error: str = ""):
-    _, outputBytes, errorBytes = execute(*parList, showCmd=False, ignoreError=True)
-    if type(output) == str:
-        output = output.encode()
-    if output and output not in outputBytes:
-        raise Exception(f"命令执行失败：{' '.join(parList)}")
-    if type(error) == str:
-        error = error.encode()
-    if error and error not in errorBytes:
-        raise Exception(f"命令执行失败：{' '.join(parList)}")
-
-
 def syncFolder(fromFolder: str, toFolder: str):
     # 删除多余目录
     toSubFolderList = sorted(getAllFolderList(toFolder), reverse=True)
@@ -309,7 +252,7 @@ def strByTimestamp(timestamp: float = time.time(), fmt: str = _DEFAULT_FMT):
     return time.strftime(fmt, ary)
 
 
-def hold(msg: str = "", showInput: bool = True, *exitValueList: str):
+def hold(msg: Optional[str] = None, showInput: bool = True, *exitValueList: str):
     msg = msg or "测试暂停，输入exit可以退出"
     exitValueList = exitValueList or ("exit",)
     inputFunc = showInput and input or getpass.getpass
@@ -318,76 +261,6 @@ def hold(msg: str = "", showInput: bool = True, *exitValueList: str):
         if inputValue in exitValueList:
             return inputValue
 
-# ---- http
-
-
-_defaultHeader = {
-    'Connection': 'keep-alive',
-    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36',
-    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
-    'Accept-Encoding': 'gzip',
-    'Accept-Language': 'zh-CN,zh;q=0.8',
-}
-
-
-# Cookie
-_cookie = http.cookiejar.CookieJar()
-_cookieProc = urllib.request.HTTPCookieProcessor(_cookie)
-_opener = urllib.request.build_opener(_cookieProc)
-urllib.request.install_opener(_opener)
-
-
-def _getHeaderByDefault(headers: dict[str, str]):
-    result = dict(_defaultHeader)
-    if headers:
-        for key, value in headers.items():
-            result[key] = value
-    return result
-
-
-def httpGet(url: str, headers: dict[str, str] = {}, timeout: int = 30, retry: int = 3):
-    method = 'GET'
-    headers = _getHeaderByDefault(headers)
-    result = None
-    response = None
-    currentTry = 0
-    while currentTry < retry:
-        currentTry += 1
-        try:
-            request = urllib.request.Request(url=url, headers=headers, method=method)
-            response = urllib.request.urlopen(request, timeout=timeout)
-            result = response.read()
-            response.close()
-            break
-        except Exception:
-            pass
-    contentEncoding = response.headers.get('Content-Encoding')
-    if contentEncoding == 'gzip':
-        result = gzip.decompress(result)
-    return result, response
-
-
-def httpPost(url: str, data=None, headers: dict[str, str] = {}, timeout: int = 30, retry: int = 3):
-    method = 'POST'
-    headers = _getHeaderByDefault(headers)
-    postData = data
-    if type(data) == dict:
-        postData = urllib.parse.urlencode(data).encode()
-    result = None
-    response = None
-    currentTry = 0
-    while currentTry < retry:
-        currentTry += 1
-        try:
-            request = urllib.request.Request(url=url, data=postData, headers=headers, method=method)
-            response = urllib.request.urlopen(request, timeout=timeout)
-            result = response.read()
-            response.close()
-            break
-        except Exception:
-            pass
-    return result, response
-
 
 IntFloatStr = Union[int, float, str]
 IntFloat = Union[int, float]
