@@ -1,12 +1,14 @@
 import asyncio
-from beniutils.http import getHeaderByDefault
 import binascii
 import hashlib
 import os
+from typing import Any, Awaitable, Optional
 
 import aiofiles
 import aiohttp
 
+from beniutils.http import getHeaderByDefault
+
 from . import makeFolder
 from .log import warning
 
@@ -20,8 +22,8 @@ def setAsyncFileMaxNum(value: int):
     _maxAsyncFileNum = value
 
 
-async def asyncAwait(*taskList):
-    resultList = []
+async def asyncAwait(*taskList: Awaitable[Any]):
+    resultList: list[Any] = []
     for task in taskList:
         resultList.append(await task)
     return resultList
@@ -117,7 +119,7 @@ def setAsyncHttpMaxNum(value: int):
     _maxAsyncHttpNum = value
 
 
-async def asyncHttpGet(url: str, headers=None, timeout: int = 30, retry: int = 3):
+async def asyncHttpGet(url: str, headers: Optional[dict[str, str]] = None, timeout: int = 30, retry: int = 3):
     initAioHttp()
     global _currentAsyncHttpNum
     headers = getHeaderByDefault(headers)
@@ -151,10 +153,10 @@ async def asyncHttpGet(url: str, headers=None, timeout: int = 30, retry: int = 3
     return result, response
 
 
-async def asyncHttpPost(url: str, data=None, headers=None, timeout: int = 30, retry: int = 3):
+async def asyncHttpPost(url: str, data: Optional[Any] = None, headers: Optional[dict[str, str]] = None, timeout: int = 30, retry: int = 3):
     initAioHttp()
     global _currentAsyncHttpNum
-    headers = _getHeaderByDefault(headers)
+    headers = getHeaderByDefault(headers)
     result = None
     response = None
     currentTry = 0
@@ -191,30 +193,30 @@ async def asyncDownload(url: str, file: str):
     await asyncWriteBinFile(file, result)
 
 
-isInitAioHttp = True
+_isInitAioHttp = True
 
 
 def initAioHttp():
 
-    global isInitAioHttp
-    if isInitAioHttp:
-        isInitAioHttp = False
+    global _isInitAioHttp
+    if _isInitAioHttp:
+        _isInitAioHttp = False
     else:
         return
 
-    from asyncio.proactor_events import _ProactorBasePipeTransport
-    from functools import wraps
+    # from asyncio.proactor_events import _ProactorBasePipeTransport
+    # from functools import wraps
 
-    # 尝试优化报错：RuntimeError: Event loop is closed
+    # # 尝试优化报错：RuntimeError: Event loop is closed
 
-    def silence_event_loop_closed(func):
-        @wraps(func)
-        def wrapper(self, *args, **kwargs):
-            try:
-                return func(self, *args, **kwargs)
-            except RuntimeError as e:
-                if str(e) != 'Event loop is closed':
-                    raise
-        return wrapper
+    # def silence_event_loop_closed(func):
+    #     @wraps(func)
+    #     def wrapper(self, *args, **kwargs):
+    #         try:
+    #             return func(self, *args, **kwargs)
+    #         except RuntimeError as e:
+    #             if str(e) != 'Event loop is closed':
+    #                 raise
+    #     return wrapper
 
-    _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
+    # _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
